pub struct LeadItem;Expand description
Vanilla lead item behavior.
The behavior does not handle the main functionality of a lead, but rather its block use functionality:
right-clicking a fence removes the knot from the user and places a knot at the right-clicked fence for
all entities (Leashables) leashed by the user.
Implementations
Sourceimpl LeadItem
impl LeadItem
Sourcepub fn bind_player_mobs(
player: &Player,
world: &Arc<World>,
pos: BlockPos,
) -> InteractionResult
pub fn bind_player_mobs( player: &Player, world: &Arc<World>, pos: BlockPos, ) -> InteractionResult
Binds all leashable mobs attached to a player to the block with the provided position.